# 0.3.3 (2014-08-03)

Reduced default amount of logging

# 0.3.2 (2014-08-03)

Fixed volume slider

# 0.3.1 (2014-07-23)

Fixed PyPI package manifest
Support for playlist folders in PyPI package

# 0.3.0 (2014-06-24)

Moped as installable Mopidy extension

# 0.2.0 (2013-12-18)

Angular version added.


# 0.1.0 (2013-12-04)

Initial Durandal version.